<?php

namespace App\JsonRpc;

interface ChatServiceInterface
{
    /**
     * 添加申请
     * @param array $data
     * @return array
     */
    public function addFriend(array $data): array;
    /**
     * 好友申请列表
     * @param array $data
     * @return array
     */
    public function getFriendsList(array $data): array;
    /**
     * 获取申请列表
     * @param array $data
     * @return array
     */
    public function getFriendsApplyList(array $data): array;

    /**
     * 更新申请
     * @param array $data
     * @return array
     */
    public function applyFriend(array $data): array;
    /**
     * 搜索好友
     * @param array $data
     * @return array
     */
    public function searchFriend(array $data): array;
    /**
     * 获取群成员
     * @param array $data
     * @return array
     */
    public function getGroupMembers(array $data): array;
    /**
     * 获取群列表
     * @param array $data
     * @return array
     */
    public function getGroupList(array $data): array;
    /**
     * 获取群信息
     * @param array $data
     * @return array
     */
    public function getGroupInfo(array $data): array;

    /**
     * 删除好友
     * @param array $data
     * @return array
     */
    public function delFriend(array $data): array;

    /**
     * 是否好友
     * @param array $data
     * @return array
     */
    public function isFriend(array $data): array;

    /**
     * 好友详情
     * @param array $data
     * @return array
     */
    public function getFriendInfo(array $data): array;

    /**
     * 添加聊天内容
     * @param array $data
     * @return array
     */
    public function addChatRecords(array $data): array;
    /**
     * 会话列表
     * @param array $data
     * @return array
     */
    public function getConversation(array $data): array;
    /**
     * 新建群
     * @param array $data
     * @return array
     */
    public function addGroup(array $data): array;
    /**
     * 更新群
     * @param array $data
     * @return array
     */
    public function updateGroup(array $data): array;
    /**
     * 删除群
     * @param array $data
     * @return array
     */
    public function delGroup(array $data): array;
    /**
     * 推出群
     * @param array $data
     * @return array
     */
    /**
     * 删除群成员
     * @param array $data
     * @return array
     */
    public function delGroupMembers(array $data): array;
    /**
     * 修改群成员
     * @param array $data
     * @return array
     */
    public function updateGroupMembers(array $data): array;
    public function quitGroup(array $data): array;
    /**
     * 加入群
     * @param array $data
     * @return array
     */
    public function joinGroup(array $data): array;
    /**
     * 获取话题列表
     * @param array $data
     * @return array
     */
    public function getTopicsList(array $data): array;
    /**
     * 添加话题
     * @param array $data
     * @return array
     */
    public function addTopic(array $data): array;
    /**
     * 更新话题
     * @param array $data
     * @return array
     */
    public function updateTopic(array $data): array;
    /**
     * 删除话题
     * @param array $data
     * @return array
     */
    public function delTopic(array $data): array;
    /**
     * 获取话题详情
     * @param array $data
     * @return array
     */
    public function getTopicInfo(array $data): array;
    /**
     * 获取话题回复
     * @param array $data
     * @return array
     */
    public function getTopicReply(array $data): array;
    /**
     * 添加话题回复
     * @param array $data
     * @return array
     */
    public function addReply(array $data): array;

    /**
     * 群聊天记录
     * @param array $data
     * @return array
     */
    public function clearGroupRecords(array $data): array;
    /**
     * 删除一条聊天记录
     * @param array $data
     * @return array
     */
    public function clearRecords(array $data): array;
    /**
     * 获取聊天记录
     * @param array $data
     * @return array
     */
    public function getRecord(array $data): array;
    /**
     * 撤回聊天记录
     * @param array $data
     * @return array
     */
    public function recallRecord(array $data): array;
    /**
     * 删除topicReply
     * @param array $data
     * @return array
     */
    public function delReply(array $data): array;
    /**
     * 删除topic所有Reply
     * @param array $data
     * @return array
     */
    public function delAllReply(array $data): array;
    /**
     * 管理后台获取所有的topic
     * @param array $data
     * @return array
     */
    public function getTopicsListAdmin(array $data): array;

}
